==> react-overlay-pack-3.0.7.tgz: package/es/DomAlign/DomAlign.js <==
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import _assertThisInitialized from "@babel/runtime/helpers/esm/assertThisInitialized";

/* global window */
import * as React from 'react';
import PropTypes from 'prop-types';
import domAlign from 'dom-align';
import rafThrottle from 'raf-throttle';

var DomAlign =
/*#__PURE__*/
function (_React$Component) {
  _inheritsLoose(DomAlign, _React$Component);

  function DomAlign(props) {
    var _this;

    _this = _React$Component.call(this, props) || this;
    _this.timeoutId = void 0;
    _this.source = void 0;
    _this.align = void 0;
    _this.source = React.createRef();
    _this.align = rafThrottle(function () {
      var _this$props = _this.props,
          target = _this$props.target,
          config = _this$props.config;

      var _assertThisInitialize = _assertThisInitialized(_assertThisInitialized(_this)),
          source = _assertThisInitialize.source;

      if (target && target.current && source && source.current) {
        // Note: Wait for two react instance ready.
        domAlign(source.current, target.current, config);
      }
    });
    return _this;
  }

  var _proto = DomAlign.prototype;

  _proto.componentDidMount = function componentDidMount() {
    var resize = this.props.resize;
    this.align();

    if (resize) {
      window.addEventListener('resize', this.align);
      window.addEventListener('scroll', this.align);
      window.addEventListener('wheel', this.align);
    }
  };

  _proto.componentDidUpdate = function componentDidUpdate() {
    var _this2 = this;

    // TODO: make it async. there is a problem of overlay in dialog case.
    this.timeoutId = setTimeout(function () {
      return _this2.align();
    });
  };

  _proto.componentWillUnmount = function componentWillUnmount() {
    var resize = this.props.resize;

    if (resize) {
      window.removeEventListener('resize', this.align);
      window.removeEventListener('scroll', this.align);
      window.removeEventListener('wheel', this.align);
    }

    if (this.align && this.align.cancel) this.align.cancel();
    if (this.timeoutId) clearTimeout(this.timeoutId);
  };

  _proto.render = function render() {
    var children = this.props.children;
    var source = this.source;
    return React.cloneElement(React.Children.only(children), {
      ref: source
    });
  };

  return DomAlign;
}(React.Component);

DomAlign.defaultProps = {
  target: undefined,
  resize: false
};
process.env.NODE_ENV !== "production" ? DomAlign.propTypes = {
  children: PropTypes.element.isRequired,
  config: PropTypes.shape({
    points: PropTypes.array,
    offset: PropTypes.array
  }),
  target: PropTypes.object,
  // eslint-disable-line
  resize: PropTypes.bool
} : void 0;
export default DomAlign;

==> react-overlay-pack-3.0.10.tgz: package/es/DomAlign/DomAlign.js <==
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import _assertThisInitialized from "@babel/runtime/helpers/esm/assertThisInitialized";

/* global window */
import * as React from 'react';
import PropTypes from 'prop-types';
import domAlign from 'dom-align';
import rafThrottle from 'raf-throttle';

var DomAlign =
/*#__PURE__*/
function (_React$PureComponent) {
  _inheritsLoose(DomAlign, _React$PureComponent);

  function DomAlign(props) {
    var _this;

    _this = _React$PureComponent.call(this, props) || this;
    _this.timeoutId = void 0;
    _this.source = void 0;
    _this.align = void 0;
    _this.source = React.createRef();
    _this.align = rafThrottle(function () {
      var _this$props = _this.props,
          target = _this$props.target,
          config = _this$props.config;

      var _assertThisInitialize = _assertThisInitialized(_assertThisInitialized(_this)),
          source = _assertThisInitialize.source;

      if (target && target.current && source && source.current) {
        // Note: Wait for two react instance ready.
        domAlign(source.current, target.current, config);
      }
    });
    return _this;
  }

  var _proto = DomAlign.prototype;

  _proto.componentDidMount = function componentDidMount() {
    var resize = this.props.resize;
    this.align();

    if (resize) {
      window.addEventListener('resize', this.align);
      window.addEventListener('scroll', this.align);
      window.addEventListener('wheel', this.align);
    }
  };

  _proto.componentDidUpdate = function componentDidUpdate() {
    var _this2 = this;

    // TODO: make it async. there is a problem of overlay in dialog case.
    this.timeoutId = setTimeout(function () {
      return _this2.align();
    });
  };

  _proto.componentWillUnmount = function componentWillUnmount() {
    var resize = this.props.resize;

    if (resize) {
      window.removeEventListener('resize', this.align);
      window.removeEventListener('scroll', this.align);
      window.removeEventListener('wheel', this.align);
    }

    if (this.align && this.align.cancel) this.align.cancel();
    if (this.timeoutId) clearTimeout(this.timeoutId);
  };

  _proto.render = function render() {
    var children = this.props.children;
    var source = this.source;
    return React.cloneElement(React.Children.only(children), {
      ref: source
    });
  };

  return DomAlign;
}(React.PureComponent);

DomAlign.defaultProps = {
  target: undefined,
  resize: false
};
process.env.NODE_ENV !== "production" ? DomAlign.propTypes = {
  children: PropTypes.element.isRequired,
  config: PropTypes.shape({
    points: PropTypes.array,
    offset: PropTypes.array
  }),
  target: PropTypes.object,
  // eslint-disable-line
  resize: PropTypes.bool
} : void 0;
export default DomAlign;
